@@ -36,6 +36,7 @@ from seaborn._core.typing import (
     OrderSpec,
     Default,
 )
+from seaborn._core.exceptions import PlotSpecError
 from seaborn._core.rules import categorical_order
 from seaborn._compat import set_scale_obj, set_layout_engine
 from seaborn.rcmod import axes_style, plotting_context
@@ -616,8 +617,8 @@ class Plot:
             - A list of values, implying a :class:`Nominal` scale (e.g. `["b", "r"]`)
 
         For more explicit control, pass a scale spec object such as :class:`Continuous`
-        or :class:`Nominal`. Or use `None` to use an "identity" scale, which treats data
-        values as literally encoding visual properties.
+        or :class:`Nominal`. Or pass `None` to use an "identity" scale, which treats
+        data values as literally encoding visual properties.
 
         Examples
         --------
@@ -1249,14 +1250,13 @@ class Plotter:
             if scale is None:
                 self._scales[var] = Scale._identity()
             else:
-                self._scales[var] = scale._setup(var_df[var], prop)
+                try:
+                    self._scales[var] = scale._setup(var_df[var], prop)
+                except Exception as err:
+                    raise PlotSpecError._during("Scale setup", var) from err
 
-            # Everything below here applies only to coordinate variables
-            # We additionally skip it when we're working with a value
-            # that is derived from a coordinate we've already processed.
-            # e.g., the Stat consumed y and added ymin/ymax. In that case,
-            # we've already setup the y scale and ymin/max are in scale space.
             if axis is None or (var != coord and coord in p._variables):
+                # Everything below here applies only to coordinate variables
                 continue
 
             # Set up an empty series to receive the transformed values.
@@ -1276,9 +1276,15 @@ class Plotter:
 
                 for layer, new_series in zip(layers, transformed_data):
                     layer_df = layer["data"].frame
-                    if var in layer_df:
-                        idx = self._get_subplot_index(layer_df, view)
+                    if var not in layer_df:
+                        continue
+
+                    idx = self._get_subplot_index(layer_df, view)
+                    try:
                         new_series.loc[idx] = view_scale(layer_df.loc[idx, var])
+                    except Exception as err:
+                        spec_error = PlotSpecError._during("Scaling operation", var)
+                        raise spec_error from err
 
             # Now the transformed data series are complete, set update the layer data
             for layer, new_series in zip(layers, transformed_data):
@@ -1309,12 +1315,22 @@ class Plotter:
                 if var not in "xy" and var in scales:
                     return getattr(scales[var], "order", None)
 
-            if "width" in mark._mappable_props:
-                width = mark._resolve(df, "width", None)
-            else:
-                width = 0.8 if "width" not in df else df["width"]  # TODO what default?
             if orient in df:
-                df["width"] = width * scales[orient]._spacing(df[orient])
+                width = pd.Series(index=df.index, dtype=float)
+                for view in subplots:
+                    view_idx = self._get_subplot_data(
+                        df, orient, view, p._shares.get(orient)
+                    ).index
+                    view_df = df.loc[view_idx]
+                    if "width" in mark._mappable_props:
+                        view_width = mark._resolve(view_df, "width", None)
+                    elif "width" in df:
+                        view_width = view_df["width"]
+                    else:
+                        view_width = 0.8  # TODO what default?
+                    spacing = scales[orient]._spacing(view_df.loc[view_idx, orient])
+                    width.loc[view_idx] = view_width * spacing
+                df["width"] = width
 
             if "baseline" in mark._mappable_props:
                 # TODO what marks should have this?
@@ -1456,8 +1472,6 @@ class Plotter:
         self, grouping_vars: list[str], df: DataFrame, subplots: list[dict[str, Any]],
     ) -> Callable[[], Generator]:
 
-        allow_empty = False  # TODO will need to recreate previous categorical plots
-
         grouping_keys = []
         grouping_vars = [
             v for v in grouping_vars if v in df and v not in ["col", "row"]
@@ -1474,7 +1488,7 @@ class Plotter:
 
                 axes_df = self._filter_subplot_data(df, view)
 
-                with pd.option_context("mode.use_inf_as_null", True):
+                with pd.option_context("mode.use_inf_as_na", True):
                     if keep_na:
                         # The simpler thing to do would be x.dropna().reindex(x.index).
                         # But that doesn't work with the way that the subset iteration
@@ -1496,7 +1510,8 @@ class Plotter:
                         subplot_keys[dim] = view[dim]
 
                 if not grouping_vars or not any(grouping_keys):
-                    yield subplot_keys, axes_df.copy(), view["ax"]
+                    if not axes_df.empty:
+                        yield subplot_keys, axes_df.copy(), view["ax"]
                     continue
 
                 grouped_df = axes_df.groupby(grouping_vars, sort=False, as_index=False)
@@ -1516,7 +1531,7 @@ class Plotter:
                         # case this option could be removed
                         df_subset = axes_df.loc[[]]
 
-                    if df_subset.empty and not allow_empty:
+                    if df_subset.empty:
                         continue
 
                     sub_vars = dict(zip(grouping_vars, key))
@@ -1644,16 +1659,8 @@ class Plotter:
                         hi = cast(float, hi) + 0.5
                     ax.set(**{f"{axis}lim": (lo, hi)})
 
-                # Nominal scale special-casing
-                if isinstance(self._scales.get(axis_key), Nominal):
-                    axis_obj.grid(False, which="both")
-                    if axis_key not in p._limits:
-                        nticks = len(axis_obj.get_major_ticks())
-                        lo, hi = -.5, nticks - .5
-                        if axis == "y":
-                            lo, hi = hi, lo
-                        set_lim = getattr(ax, f"set_{axis}lim")
-                        set_lim(lo, hi, auto=None)
+                if axis_key in self._scales:  # TODO when would it not be?
+                    self._scales[axis_key]._finalize(p, axis_obj)
 
         engine_default = None if p._target is not None else "tight"
         layout_engine = p._layout_spec.get("engine", engine_default)
