@@ -1,13 +1,11 @@
 """Control plot style and scaling using the matplotlib rcParams interface."""
-import warnings
 import functools
-from distutils.version import LooseVersion
 import matplotlib as mpl
 from cycler import cycler
-from . import palettes, _orig_rc_params
+from . import palettes
 
 
-__all__ = ["set", "reset_defaults", "reset_orig",
+__all__ = ["set_theme", "set", "reset_defaults", "reset_orig",
            "axes_style", "set_style", "plotting_context", "set_context",
            "set_palette"]
 
@@ -50,7 +48,7 @@ _style_keys = [
     "axes.spines.right",
     "axes.spines.top",
 
-    ]
+]
 
 _context_keys = [
 
@@ -60,6 +58,7 @@ _context_keys = [
     "xtick.labelsize",
     "ytick.labelsize",
     "legend.fontsize",
+    "legend.title_fontsize",
 
     "axes.linewidth",
     "grid.linewidth",
@@ -77,27 +76,29 @@ _context_keys = [
     "xtick.minor.size",
     "ytick.minor.size",
 
-    ]
-
-if LooseVersion(mpl.__version__) >= "3.0":
-    _context_keys.append("legend.title_fontsize")
+]
 
 
-def set(context="notebook", style="darkgrid", palette="deep",
-        font="sans-serif", font_scale=1, color_codes=True, rc=None):
-    """Set aesthetic parameters in one step.
+def set_theme(context="notebook", style="darkgrid", palette="deep",
+              font="sans-serif", font_scale=1, color_codes=True, rc=None):
+    """
+    Set aspects of the visual theme for all matplotlib and seaborn plots.
 
-    Each set of parameters can be set directly or temporarily, see the
-    referenced functions below for more information.
+    This function changes the global defaults for all plots using the
+    matplotlib rcParams system. The themeing is decomposed into several distinct
+    sets of parameter values.
+
+    The options are illustrated in the :doc:`aesthetics <../tutorial/aesthetics>`
+    and :doc:`color palette <../tutorial/color_palettes>` tutorials.
 
     Parameters
     ----------
     context : string or dict
-        Plotting context parameters, see :func:`plotting_context`
+        Scaling parameters, see :func:`plotting_context`.
     style : string or dict
-        Axes style parameters, see :func:`axes_style`
+        Axes style parameters, see :func:`axes_style`.
     palette : string or sequence
-        Color palette, see :func:`color_palette`
+        Color palette, see :func:`color_palette`.
     font : string
         Font family, see matplotlib font manager.
     font_scale : float, optional
@@ -109,6 +110,11 @@ def set(context="notebook", style="darkgrid", palette="deep",
     rc : dict or None
         Dictionary of rc parameter mappings to override the above.
 
+    Examples
+    --------
+
+    .. include:: ../docstrings/set_theme.rst
+
     """
     set_context(context, font_scale)
     set_style(style, rc={"font.family": font})
@@ -117,6 +123,15 @@ def set(context="notebook", style="darkgrid", palette="deep",
         mpl.rcParams.update(rc)
 
 
+def set(*args, **kwargs):
+    """
+    Alias for :func:`set_theme`, which is the preferred interface.
+
+    This function may be removed in the future.
+    """
+    set_theme(*args, **kwargs)
+
+
 def reset_defaults():
     """Restore all RC params to default settings."""
     mpl.rcParams.update(mpl.rcParamsDefault)
@@ -124,24 +139,29 @@ def reset_defaults():
 
 def reset_orig():
     """Restore all RC params to original settings (respects custom rc)."""
-    with warnings.catch_warnings():
-        warnings.simplefilter('ignore', mpl.cbook.MatplotlibDeprecationWarning)
-        mpl.rcParams.update(_orig_rc_params)
+    from . import _orig_rc_params
+    mpl.rcParams.update(_orig_rc_params)
 
 
 def axes_style(style=None, rc=None):
-    """Return a parameter dict for the aesthetic style of the plots.
+    """
+    Get the parameters that control the general style of the plots.
 
-    This affects things like the color of the axes, whether a grid is
-    enabled by default, and other aesthetic elements.
+    The style parameters control properties like the color of the background and
+    whether a grid is enabled by default. This is accomplished using the
+    matplotlib rcParams system.
 
-    This function returns an object that can be used in a ``with`` statement
-    to temporarily change the style parameters.
+    The options are illustrated in the
+    :doc:`aesthetics tutorial <../tutorial/aesthetics>`.
+
+    This function can also be used as a context manager to temporarily
+    alter the global defaults. See :func:`set_theme` or :func:`set_style`
+    to modify the global defaults for all plots.
 
     Parameters
     ----------
-    style : dict, None, or one of {darkgrid, whitegrid, dark, white, ticks}
-        A dictionary of parameters or the name of a preconfigured set.
+    style : None, dict, or one of {darkgrid, whitegrid, dark, white, ticks}
+        A dictionary of parameters or the name of a preconfigured style.
     rc : dict, optional
         Parameter mappings to override the values in the preset seaborn
         style dictionaries. This only updates parameters that are
@@ -149,20 +169,8 @@ def axes_style(style=None, rc=None):
 
     Examples
     --------
-    >>> st = axes_style("whitegrid")
 
-    >>> set_style("ticks", {"xtick.major.size": 8, "ytick.major.size": 8})
-
-    >>> import matplotlib.pyplot as plt
-    >>> with axes_style("white"):
-    ...     f, ax = plt.subplots()
-    ...     ax.plot(x, y)               # doctest: +SKIP
-
-    See Also
-    --------
-    set_style : set the matplotlib parameters for a seaborn theme
-    plotting_context : return a parameter dict to to scale plot elements
-    color_palette : define the color palette for a plot
+    .. include:: ../docstrings/axes_style.rst
 
     """
     if style is None:
@@ -174,7 +182,7 @@ def axes_style(style=None, rc=None):
     else:
         styles = ["white", "dark", "whitegrid", "darkgrid", "ticks"]
         if style not in styles:
-            raise ValueError("style must be one of %s" % ", ".join(styles))
+            raise ValueError(f"style must be one of {', '.join(styles)}")
 
         # Define colors here
         dark_gray = ".15"
@@ -210,17 +218,17 @@ def axes_style(style=None, rc=None):
             "xtick.top": False,
             "ytick.right": False,
 
-            }
+        }
 
         # Set grid on or off
         if "grid" in style:
             style_dict.update({
                 "axes.grid": True,
-                })
+            })
         else:
             style_dict.update({
                 "axes.grid": False,
-                })
+            })
 
         # Set the color of the background, spines, and grids
         if style.startswith("dark"):
@@ -235,7 +243,7 @@ def axes_style(style=None, rc=None):
                 "axes.spines.right": True,
                 "axes.spines.top": True,
 
-                })
+            })
 
         elif style == "whitegrid":
             style_dict.update({
@@ -249,7 +257,7 @@ def axes_style(style=None, rc=None):
                 "axes.spines.right": True,
                 "axes.spines.top": True,
 
-                })
+            })
 
         elif style in ["white", "ticks"]:
             style_dict.update({
@@ -263,19 +271,19 @@ def axes_style(style=None, rc=None):
                 "axes.spines.right": True,
                 "axes.spines.top": True,
 
-                })
+            })
 
         # Show or hide the axes ticks
         if style == "ticks":
             style_dict.update({
                 "xtick.bottom": True,
                 "ytick.left": True,
-                })
+            })
         else:
             style_dict.update({
                 "xtick.bottom": False,
                 "ytick.left": False,
-                })
+            })
 
     # Remove entries that are not defined in the base list of valid keys
     # This lets us handle matplotlib <=/> 2.0
@@ -293,15 +301,22 @@ def axes_style(style=None, rc=None):
 
 
 def set_style(style=None, rc=None):
-    """Set the aesthetic style of the plots.
+    """
+    Set the parameters that control the general style of the plots.
 
-    This affects things like the color of the axes, whether a grid is
-    enabled by default, and other aesthetic elements.
+    The style parameters control properties like the color of the background and
+    whether a grid is enabled by default. This is accomplished using the
+    matplotlib rcParams system.
+
+    The options are illustrated in the
+    :doc:`aesthetics tutorial <../tutorial/aesthetics>`.
+
+    See :func:`axes_style` to get the parameter values.
 
     Parameters
     ----------
-    style : dict, None, or one of {darkgrid, whitegrid, dark, white, ticks}
-        A dictionary of parameters or the name of a preconfigured set.
+    style : dict, or one of {darkgrid, whitegrid, dark, white, ticks}
+        A dictionary of parameters or the name of a preconfigured style.
     rc : dict, optional
         Parameter mappings to override the values in the preset seaborn
         style dictionaries. This only updates parameters that are
@@ -309,16 +324,8 @@ def set_style(style=None, rc=None):
 
     Examples
     --------
-    >>> set_style("whitegrid")
 
-    >>> set_style("ticks", {"xtick.major.size": 8, "ytick.major.size": 8})
-
-    See Also
-    --------
-    axes_style : return a dict of parameters or use in a ``with`` statement
-                 to temporarily set the style.
-    set_context : set parameters to scale plot elements
-    set_palette : set the default color palette for figures
+    .. include:: ../docstrings/set_style.rst
 
     """
     style_object = axes_style(style, rc)
@@ -326,20 +333,25 @@ def set_style(style=None, rc=None):
 
 
 def plotting_context(context=None, font_scale=1, rc=None):
-    """Return a parameter dict to scale elements of the figure.
+    """
+    Get the parameters that control the scaling of plot elements.
 
-    This affects things like the size of the labels, lines, and other
-    elements of the plot, but not the overall style. The base context
-    is "notebook", and the other contexts are "paper", "talk", and "poster",
-    which are version of the notebook parameters scaled by .8, 1.3, and 1.6,
-    respectively.
+    This affects things like the size of the labels, lines, and other elements
+    of the plot, but not the overall style. This is accomplished using the
+    matplotlib rcParams system.
 
-    This function returns an object that can be used in a ``with`` statement
-    to temporarily change the context parameters.
+    The base context is "notebook", and the other contexts are "paper", "talk",
+    and "poster", which are version of the notebook parameters scaled by different
+    values. Font elements can also be scaled independently of (but relative to)
+    the other values.
+
+    This function can also be used as a context manager to temporarily
+    alter the global defaults. See :func:`set_theme` or :func:`set_context`
+    to modify the global defaults for all plots.
 
     Parameters
     ----------
-    context : dict, None, or one of {paper, notebook, talk, poster}
+    context : None, dict, or one of {paper, notebook, talk, poster}
         A dictionary of parameters or the name of a preconfigured set.
     font_scale : float, optional
         Separate scaling factor to independently scale the size of the
@@ -351,22 +363,8 @@ def plotting_context(context=None, font_scale=1, rc=None):
 
     Examples
     --------
-    >>> c = plotting_context("poster")
 
-    >>> c = plotting_context("notebook", font_scale=1.5)
-
-    >>> c = plotting_context("talk", rc={"lines.linewidth": 2})
-
-    >>> import matplotlib.pyplot as plt
-    >>> with plotting_context("paper"):
-    ...     f, ax = plt.subplots()
-    ...     ax.plot(x, y)                 # doctest: +SKIP
-
-    See Also
-    --------
-    set_context : set the matplotlib parameters to scale plot elements
-    axes_style : return a dict of parameters defining a figure style
-    color_palette : define the color palette for a plot
+    .. include:: ../docstrings/plotting_context.rst
 
     """
     if context is None:
@@ -379,10 +377,10 @@ def plotting_context(context=None, font_scale=1, rc=None):
 
         contexts = ["paper", "notebook", "talk", "poster"]
         if context not in contexts:
-            raise ValueError("context must be in %s" % ", ".join(contexts))
+            raise ValueError(f"context must be in {', '.join(contexts)}")
 
         # Set up dictionary of default parameters
-        base_context = {
+        texts_base_context = {
 
             "font.size": 12,
             "axes.labelsize": 12,
@@ -390,6 +388,11 @@ def plotting_context(context=None, font_scale=1, rc=None):
             "xtick.labelsize": 11,
             "ytick.labelsize": 11,
             "legend.fontsize": 11,
+            "legend.title_fontsize": 12,
+
+        }
+
+        base_context = {
 
             "axes.linewidth": 1.25,
             "grid.linewidth": 1,
@@ -407,18 +410,15 @@ def plotting_context(context=None, font_scale=1, rc=None):
             "xtick.minor.size": 4,
             "ytick.minor.size": 4,
 
-            }
-
-        if LooseVersion(mpl.__version__) >= "3.0":
-            base_context["legend.title_fontsize"] = 12
+        }
+        base_context.update(texts_base_context)
 
         # Scale all the parameters by the same factor depending on the context
         scaling = dict(paper=.8, notebook=1, talk=1.5, poster=2)[context]
         context_dict = {k: v * scaling for k, v in base_context.items()}
 
         # Now independently scale the fonts
-        font_keys = ["axes.labelsize", "axes.titlesize", "legend.fontsize",
-                     "xtick.labelsize", "ytick.labelsize", "font.size"]
+        font_keys = texts_base_context.keys()
         font_dict = {k: context_dict[k] * font_scale for k in font_keys}
         context_dict.update(font_dict)
 
@@ -434,17 +434,23 @@ def plotting_context(context=None, font_scale=1, rc=None):
 
 
 def set_context(context=None, font_scale=1, rc=None):
-    """Set the plotting context parameters.
+    """
+    Set the parameters that control the scaling of plot elements.
 
-    This affects things like the size of the labels, lines, and other
-    elements of the plot, but not the overall style. The base context
-    is "notebook", and the other contexts are "paper", "talk", and "poster",
-    which are version of the notebook parameters scaled by .8, 1.3, and 1.6,
-    respectively.
+    This affects things like the size of the labels, lines, and other elements
+    of the plot, but not the overall style. This is accomplished using the
+    matplotlib rcParams system.
+
+    The base context is "notebook", and the other contexts are "paper", "talk",
+    and "poster", which are version of the notebook parameters scaled by different
+    values. Font elements can also be scaled independently of (but relative to)
+    the other values.
+
+    See :func:`plotting_context` to get the parameter values.
 
     Parameters
     ----------
-    context : dict, None, or one of {paper, notebook, talk, poster}
+    context : dict, or one of {paper, notebook, talk, poster}
         A dictionary of parameters or the name of a preconfigured set.
     font_scale : float, optional
         Separate scaling factor to independently scale the size of the
@@ -456,18 +462,8 @@ def set_context(context=None, font_scale=1, rc=None):
 
     Examples
     --------
-    >>> set_context("paper")
 
-    >>> set_context("talk", font_scale=1.4)
-
-    >>> set_context("talk", rc={"lines.linewidth": 2})
-
-    See Also
-    --------
-    plotting_context : return a dictionary of rc parameters, or use in
-                       a ``with`` statement to temporarily set the context.
-    set_style : set the default parameters for figure style
-    set_palette : set the default color palette for figures
+    .. include:: ../docstrings/set_context.rst
 
     """
     context_object = plotting_context(context, font_scale, rc)
@@ -509,8 +505,7 @@ def set_palette(palette, n_colors=None, desat=None, color_codes=False):
     Parameters
     ----------
     palette : seaborn color paltte | matplotlib colormap | hls | husl
-        Palette definition. Should be something that :func:`color_palette`
-        can process.
+        Palette definition. Should be something :func:`color_palette` can process.
     n_colors : int
         Number of colors in the cycle. The default number of colors will depend
         on the format of ``palette``, see the :func:`color_palette`
@@ -521,12 +516,6 @@ def set_palette(palette, n_colors=None, desat=None, color_codes=False):
         If ``True`` and ``palette`` is a seaborn palette, remap the shorthand
         color codes (e.g. "b", "g", "r", etc.) to the colors from this palette.
 
-    Examples
-    --------
-    >>> set_palette("Reds")
-
-    >>> set_palette("Set1", 8, .75)
-
     See Also
     --------
     color_palette : build a color palette or set the color cycle temporarily
@@ -538,7 +527,6 @@ def set_palette(palette, n_colors=None, desat=None, color_codes=False):
     colors = palettes.color_palette(palette, n_colors, desat)
     cyl = cycler('color', colors)
     mpl.rcParams['axes.prop_cycle'] = cyl
-    mpl.rcParams["patch.facecolor"] = colors[0]
     if color_codes:
         try:
             palettes.set_color_codes(palette)
